import time

from netforce.model import Model, fields, get_model
from netforce.access import get_active_company

class Doctor(Model):
    _name="clinic.doctor"
    _string="Doctor"
    _audit_log=True
    _multi_company=True

    def _get_age(self,ids,context):
        res={}
        year_now=int(time.strftime("%Y"))
        for obj in self.browse(ids):
            age=0
            if obj.birthday:
                year_bd=int(obj.birthday[0:4])
                age=year_now-year_bd
            res[obj.id]=age
        return res

    _fields={
        "number": fields.Char("Doctor No.",required=True,search=True),
        "name": fields.Char("Name",required=True,search=True),
        "identification" : fields.Char("Identification"),
        "expiry_card" : fields.Date("Expiry Card"),
        "birthday": fields.Date("Birthday",search=True),
        "age": fields.Integer("Age", function="_get_age"),
        "type": fields.Selection([["temporary","Temporary"],["permanent","Permanent"]],"Type"),
        "mobile": fields.Char("Mobile",required=False,search=True),
        "phone": fields.Char("Phone",search=True),
        'email': fields.Char("Email"),
        "prof_license" : fields.Char("Professional License."),
        "prof_license_date" : fields.Date("Professional License Date"),
        "birthday": fields.Date("BirthDay",search=True),
        "department_id": fields.Many2One("clinic.department", "Department",search=True),
        "patients": fields.Many2Many("clinic.patient","Patients"),
        "addresses": fields.One2Many("address","related_id","Addresses"),
        "comments": fields.One2Many("message","related_id","Comments"),
        "visits": fields.One2Many("clinic.visit","nurse_id","Visits"),
        "hd_cases": fields.One2Many("clinic.hd.case","nurse_id","HD Cases"),
        "company_id": fields.Many2One("company","Company"),
        "user_id": fields.Many2One("base.user","User"),
        'picture': fields.File("Picture"),
    }

    def _get_number(self,context={}):
        while 1:
            num=get_model("sequence").get_number("sale_order")
            if not num:
                return None
            res=self.search([["number","=",num]])
            if not res:
                return num
            get_model("sequence").increment("sale_order")


    _defaults={
        "type": "temporary",
        "date": lambda *a: time.strftime("%Y-%m-%d"),
        "number": _get_number,
        "company_id": lambda *a: get_active_company(),
    }
    _order="date desc,number desc"


    def void(self,ids,context={}):
        obj=self.browse(ids)[0]
        obj.write({"state":"voided"})


Doctor.register()
